# These are the codes for the phyloegentic mixed models used in Garamszegi et al. 2023 "Evolution of relative brain size in dogs – no effects of selection for breed function, litter size or longevity". 
# The codes rely on the breed-specific dataset of the phenotypic traits ("dog_brain_data.txt"), and the similarity matrices as defined by genetic distances ("phylo_mtx.txt") and haplotype sharing ("haplo_mtx.txt").
# The phenotypic data is the same as in Table S1 without breed names, the following abbreviations are used for column names: abr = Abbreviation, body= Body mass, brain = Brain volume, dist = Genetic distance from the wolf, akc = AKC functional category, head = Head shape, long = Age of death, fec = Litter size
# The similarity matrices "phylo_mtx.txt" and "haplo_mtx.txt" are from Garamszegi et al. (2020)

#prepare desktop
rm(list=ls())
library(MCMCglmm)
setwd("~/Dropbox/ running projects/brain size decrease within dogs/MS/")

#import data
xbreeds <-read.table(file="dog_brain_data.txt",header=T,sep="\t",fill=T, strip.white=T, dec = ".")
xbreeds$abr=as.character(xbreeds$abr)
xbreeds$log_body=log10(xbreeds$body)
xbreeds$log_brain=log10(xbreeds$brain)
str(xbreeds)

phylo_mtx=read.csv("phylo_mtx.txt", row.names=1)
phylo_mtx=as.matrix(phylo_mtx)
haplo_mtx=read.csv("haplo_mtx.txt", row.names=1)
haplo_mtx=as.matrix(haplo_mtx)

phylo_mtx[1:5, 1:5]
haplo_mtx[1:5, 1:5]

dim(phylo_mtx)
dim(haplo_mtx)


#==== ALLOMETRIC REGGRESSIONS IN DOGS AND WOLF (model in Table 1) ==================

#trim the similarity matrices to the data at hand
m.gen=m2.corr2[xbreedNwolf_phylo$abbr, xbreedNwolf_phylo$abbr]
cbind(rownames(m.gen),xbreedNwolf_phylo$abbr)
Msvd1 = svd(as.matrix(m.gen))
Msvd1 = Msvd1$v%*%(t(Msvd1$u)*sqrt(Msvd1$d))
xbreedNwolf_phylo$phylo = Msvd1

m.hapl=m3.final[xbreedNwolf_phylo$abbr, xbreedNwolf_phylo$abbr]
cbind(rownames(m.hapl),xbreedNwolf_phylo$abbr)
Msvd2 = svd(as.matrix(m.hapl))
Msvd2 = Msvd2$v%*%(t(Msvd2$u)*sqrt(Msvd2$d))
xbreedNwolf_phylo$haplo = Msvd2

#define priors
prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))

#the models
mod0=MCMCglmm(log10(br_vol_imp) ~ log10(body), random=~idv(phylo)+idv(haplo), data= xbreedNwolf_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod1=MCMCglmm(log10(br_vol_imp) ~ log10(body)+species, random=~idv(phylo)+idv(haplo), data= xbreedNwolf_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod2=MCMCglmm(log10(br_vol_imp) ~ log10(body)*species, random=~idv(phylo)+idv(haplo), data= xbreedNwolf_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
 
c(mod0$DIC,mod1$DIC,mod2$DIC)
summary(mod2)             
              
              
#==== PAIRWISE COMPARISON OF BRAIN SIZE BETWEEN DOGS AND WOLF WITH THE SAME SIZE (model in Table 2)  ==================



#==== CHANGE IN BRAIN SIZE AFTER DOMESTICATION (model corresponding to Figure 4.B)==================

mod5_nophylo <- lm(log10(br_vol_imp)~ dist+log10(body), data= xbreed_phylo)
mod6_nophylo <- lm(log10(br_vol_imp)~poly(dist,2,raw=TRUE)+log10(body), data= xbreed_phylo)
anova(mod5_nophylo, mod6_nophylo)
summary(mod5_nophylo)

mod7_nophylo <- lm(log10(br_vol_imp)~ wdist+log10(body), data= xbreed_phylo)
mod8_nophylo <- lm(log10(br_vol_imp)~poly(wdist,2,raw=TRUE)+log10(body), data= xbreed_phylo)
anova(mod7_nophylo, mod8_nophylo)
summary(mod7_nophylo)

            
#==== HEAD SHAPE AND FUNCTION (model in Table 3) ==================

#take the variables of interest and create a data table with no missing values
xbreeds_akc=na.omit(xbreeds[,c("abr","log_body", "log_brain", "akc", "head")])
xbreeds_akc=xbreeds_akc[xbreeds_akc$abr %in% rownames(phylo_mtx),]

#trim the similarity matrices to the data at hand
phylo_mtx_akc=phylo_mtx[xbreeds_akc$abr,xbreeds_akc$abr]
Msvd1 = svd(as.matrix(phylo_mtx_akc))
Msvd1 = Msvd1$v%*%(t(Msvd1$u)*sqrt(Msvd1$d))
xbreeds_akc$phylo = Msvd1

haplo_mtx_akc=haplo_mtx[xbreeds_akc$abr,xbreeds_akc$abr]
Msvd2 = svd(as.matrix(haplo_mtx_akc))
Msvd2 = Msvd2$v%*%(t(Msvd2$u)*sqrt(Msvd2$d))
xbreeds_akc$haplo = Msvd2

#define priors
prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))

#models
mod9=MCMCglmm(log10(br_vol_imp) ~ log10(body), random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod10=MCMCglmm(log10(br_vol_imp) ~ log10(body)+AKC, random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod11=MCMCglmm(log10(br_vol_imp) ~ log10(body)*AKC, random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)              
c(mod9$DIC, mod10$DIC, mod11$DIC)
summary(mod9)  
summary(mod10)
summary(mod11) 

prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))
mod15=MCMCglmm(log10(br_vol_imp) ~ log10(body)+head, random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod16=MCMCglmm(log10(br_vol_imp) ~ log10(body)+AKC+head, random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod17=MCMCglmm(log10(br_vol_imp) ~ log10(body)+AKC*head, random=~idv(phylo)+idv(haplo), data= xbreed_phylo_AKC,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)              
c(mod9$DIC, mod10$DIC, mod11$DIC, mod15$DIC, mod16$DIC,mod17$DIC)
summary(mod15)
summary(mod16) 
summary(mod17)

prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))
mod12=MCMCglmm(log10(br_vol_imp) ~ log10(body), random=~idv(phylo)+idv(haplo), data= xbreed_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod13=MCMCglmm(log10(br_vol_imp) ~ log10(body)+head, random=~idv(phylo)+idv(haplo), data= xbreed_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=10, verbose=T)
mod14=MCMCglmm(log10(br_vol_imp) ~ log10(body)*head, random=~idv(phylo)+idv(haplo), data= xbreed_phylo,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)               
              

c(mod12$DIC, mod13$DIC, mod14$DIC)
summary(mod12)  
summary(mod13)
summary(mod14)   



#==== LIFE HISTORY (models in Table 4)==================  

###longevity

#take the variables of interest and create a data table with no missing values
xbreed3_phylo_long=na.omit(xbreed3_phylo[,c("abbr","br_vol_imp", "body", "AODmed","head","AKC")])
rownames(xbreed3_phylo_long)=as.character(xbreed3_phylo_long$abbr)
xbreed3_phylo_long = xbreed3_phylo_long[intersect(xbreed3_phylo_long$abbr, rownames(m2.corr2)),]

#trim the similarity matrices to the data at hand
m.gen=m2.corr2[xbreed3_phylo_long$abbr, xbreed3_phylo_long$abbr]
Msvd1 = svd(as.matrix(m.gen))
Msvd1 = Msvd1$v%*%(t(Msvd1$u)*sqrt(Msvd1$d))
xbreed3_phylo_long$phylo = Msvd1

m.hapl=m3.final[xbreed3_phylo_long$abbr, xbreed3_phylo_long$abbr]
Msvd2 = svd(as.matrix(m.hapl))
Msvd2 = Msvd2$v%*%(t(Msvd2$u)*sqrt(Msvd2$d))
xbreed3_phylo_long$haplo = Msvd2

#define priors
prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))

#the models
mod15=MCMCglmm(log10(br_vol_imp) ~ log10(body), random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_long,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod16=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ AODmed, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_long,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=10, verbose=T)
mod17=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ AODmed+head, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_long,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)   
mod18=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ AODmed*head, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_long,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T) 

c(mod15$DIC, mod16$DIC, mod17$DIC,mod18$DIC )
summary(mod16)  
summary(mod17)
summary(mod18)  



### litter size  

#take the variables of interest and create a data table with no missing values
xbreed3_phylo_fec=na.omit(xbreed3_phylo[,c("abbr","br_vol_imp", "body", "LS","head")])
rownames(xbreed3_phylo_fec)=as.character(xbreed3_phylo_fec$abbr)
xbreed3_phylo_fec = xbreed3_phylo_fec[intersect(xbreed3_phylo_fec$abbr, rownames(m2.corr2)),]

#trim the similarity matrices to the data at hand
m.gen=m2.corr2[xbreed3_phylo_fec$abbr, xbreed3_phylo_fec$abbr]
Msvd1 = svd(as.matrix(m.gen))
Msvd1 = Msvd1$v%*%(t(Msvd1$u)*sqrt(Msvd1$d))
xbreed3_phylo_fec$phylo = Msvd1

m.hapl=m3.final[xbreed3_phylo_fec$abbr, xbreed3_phylo_fec$abbr]
Msvd2 = svd(as.matrix(m.hapl))
Msvd2 = Msvd2$v%*%(t(Msvd2$u)*sqrt(Msvd2$d))
xbreed3_phylo_fec$haplo = Msvd2

#define priors
prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))

#models
mod19=MCMCglmm(log10(br_vol_imp) ~ log10(body), random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_fec,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod20=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ LS, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_fec,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=10, verbose=T)
mod21=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ LS+head, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_fec,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)   
mod22=MCMCglmm(log10(br_vol_imp) ~ log10(body)+ LS*head, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_fec,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T) 

c(mod19$DIC, mod20$DIC, mod21$DIC,mod22$DIC)
summary(mod19)
summary(mod20)  
summary(mod21)
summary(mod22)  
  
  
#==== LIFE HISTORY (models in Table S2) ================== 

#models with phylogeny
xbreed3_phylo_all=na.omit(xbreed3_phylo[,c("abbr","br_vol_imp", "body", "LS","head", "AKC", "AODmed")])
rownames(xbreed3_phylo_all)=as.character(xbreed3_phylo_all$abbr)
nrow(xbreed3_phylo_all)

mod22_nophylo <- lm(log10(br_vol_imp)~ log10(body) + AKC + head + AODmed + LS, data= xbreed3_phylo_all)
summary(mod22_nophylo)

xbreed3_phylo_all = xbreed3_phylo_all[intersect(xbreed3_phylo_all$abbr, rownames(m2.corr2)),]

m.gen=m2.corr2[xbreed3_phylo_all$abbr, xbreed3_phylo_all$abbr]
Msvd1 = svd(as.matrix(m.gen))
Msvd1 = Msvd1$v%*%(t(Msvd1$u)*sqrt(Msvd1$d))
xbreed3_phylo_all$phylo = Msvd1

m.hapl=m3.final[xbreed3_phylo_all$abbr, xbreed3_phylo_all$abbr]
Msvd2 = svd(as.matrix(m.hapl))
Msvd2 = Msvd2$v%*%(t(Msvd2$u)*sqrt(Msvd2$d))
xbreed3_phylo_all$haplo = Msvd2

prior<-list(G=list(G1=list(V=1,nu=1),G2=list(V=1,nu=1)),R=list(V=1,nu=0.002))
mod22=MCMCglmm(log10(br_vol_imp) ~ log10(body) + AKC + head + AODmed + LS, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_all,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)
mod22.0=MCMCglmm(log10(br_vol_imp) ~ log10(body) + head + AODmed + LS, random=~idv(phylo)+idv(haplo), data= xbreed3_phylo_all,
              family="gaussian", prior=prior, nitt=130000,burnin=30000,thin=100, verbose=T)

c(mod22$DIC, mod22.0$DIC)
summary(mod22)  
summary(mod22.0)
  
           

save.image("brain_decrease_MCMCglmm.Rdata")